diff -r d56189ba97a1 src/core/nginx.c
--- a/src/core/nginx.c	Tue Jan 22 12:03:43 2008 +0100
+++ b/src/core/nginx.c	Tue Jan 22 15:15:15 2008 +0100
@@ -632,6 +632,18 @@ ngx_getopt(ngx_cycle_t *cycle, int argc,
             ngx_test_config = 1;
             break;
 
+        case 'p':
+            if (argv[i + 1] == NULL) {
+                ngx_log_error(NGX_LOG_EMERG, cycle->log, 0,
+                              "the option: \"%s\" requires directory name",
+                              argv[i]);
+                return NGX_ERROR;
+            }
+
+            cycle->root.data = (u_char *) argv[++i];
+            cycle->root.len = ngx_strlen(cycle->root.data);
+            break;
+ 
         case 'c':
             if (argv[i + 1] == NULL) {
                 ngx_log_error(NGX_LOG_EMERG, cycle->log, 0,
@@ -649,6 +661,11 @@ ngx_getopt(ngx_cycle_t *cycle, int argc,
                           "invalid option: \"%s\"", argv[i]);
             return NGX_ERROR;
         }
+    }
+
+    if (cycle->root.data == NULL) {
+        cycle->root.len = sizeof(NGX_PREFIX) - 1;
+        cycle->root.data = (u_char *) NGX_PREFIX;
     }
 
     if (cycle->conf_file.data == NULL) {
diff -r d56189ba97a1 src/core/ngx_cycle.c
--- a/src/core/ngx_cycle.c	Tue Jan 22 12:03:43 2008 +0100
+++ b/src/core/ngx_cycle.c	Tue Jan 22 15:15:15 2008 +0100
@@ -74,9 +74,16 @@ ngx_init_cycle(ngx_cycle_t *old_cycle)
     cycle->pool = pool;
     cycle->log = log;
     cycle->old_cycle = old_cycle;
-    cycle->root.len = sizeof(NGX_PREFIX) - 1;
-    cycle->root.data = (u_char *) NGX_PREFIX;
 
+
+    cycle->root.len = old_cycle->root.len;
+    cycle->root.data = ngx_palloc(pool, old_cycle->root.len + 1);
+    if (cycle->root.data == NULL) {
+        ngx_destroy_pool(pool);
+        return NULL;
+    }
+    ngx_cpystrn(cycle->root.data, old_cycle->root.data,
+                old_cycle->root.len + 1);
 
     cycle->conf_file.len = old_cycle->conf_file.len;
     cycle->conf_file.data = ngx_palloc(pool, old_cycle->conf_file.len + 1);
